@@ -5,7 +5,7 @@
 # class demonoid.hpc.                                                     #
 ###########################################################################
 
-plot.demonoid.hpc <- function(x, BurnIn=1, Data=NULL, PDF=FALSE,
+plot.demonoid.hpc <- function(x, BurnIn=0, Data=NULL, PDF=FALSE,
      Parms=NULL, ...)
      {
      ### Initial Checks
@@ -15,7 +15,8 @@ plot.demonoid.hpc <- function(x, BurnIn=1, Data=NULL, PDF=FALSE,
      Chains <- length(x)
      if(is.null(Data)) stop("The Data argument is NULL.")
      nn <- nrow(x[[1]]$Posterior1)
-     if(BurnIn >= nn) BurnIn <- 1
+     if(BurnIn >= nn) BurnIn <- 0
+     Stat.at <- BurnIn + 1
      ### Selecting Parms
      if(is.null(Parms)) {
           Posterior <- list()
@@ -48,34 +49,34 @@ plot.demonoid.hpc <- function(x, BurnIn=1, Data=NULL, PDF=FALSE,
      else {par(mfrow=c(3,3), ask=TRUE)}
      ### Plot Parameters
      for (j in 1:ncol(Posterior[[1]])) {
-          plot(BurnIn:nn, Posterior[[1]][BurnIn:nn,j],
+          plot(Stat.at:nn, Posterior[[1]][Stat.at:nn,j],
                ylim=c(min(matrix(sapply(Posterior, function(x) {
-                         min = min(x[,j])}), nn, Chains)[BurnIn:nn,]),
+                         min = min(x[,j])}), nn, Chains)[Stat.at:nn,]),
                     max(matrix(sapply(Posterior, function(x) {
-                         max = max(x[,j])}), nn, Chains)[BurnIn:nn,])),
+                         max = max(x[,j])}), nn, Chains)[Stat.at:nn,])),
                col=1, type="l", xlab="Iterations", ylab="Value",
                main=colnames(Posterior[[1]])[j])
           for (n in 2:Chains) {
-               lines(BurnIn:nn, Posterior[[n]][BurnIn:nn,j], col=n)}
-          plot(density(Posterior[[1]][BurnIn:nn,j]),
+               lines(Stat.at:nn, Posterior[[n]][Stat.at:nn,j], col=n)}
+          plot(density(Posterior[[1]][Stat.at:nn,j]),
                col=1, xlab="Value", main=colnames(Posterior[[1]])[j])
-          polygon(density(Posterior[[1]][BurnIn:nn,j]),
+          polygon(density(Posterior[[1]][Stat.at:nn,j]),
                col="black", border="black")
           for (n in 2:Chains) {
-               lines(density(Posterior[[n]][BurnIn:nn,j]), col=n)}
+               lines(density(Posterior[[n]][Stat.at:nn,j]), col=n)}
           abline(v=0, col="red", lty=2)
           ### Only plot an ACF if there's > 1 unique values
-          if(!is.constant(Posterior[[1]][BurnIn:nn,j])) {
-               z <- acf(Posterior[[1]][BurnIn:nn,j], plot=FALSE)
-               se <- 1/sqrt(length(Posterior[[1]][BurnIn:nn,j]))
+          if(!is.constant(Posterior[[1]][Stat.at:nn,j])) {
+               z <- acf(Posterior[[1]][Stat.at:nn,j], plot=FALSE)
+               se <- 1/sqrt(length(Posterior[[1]][Stat.at:nn,j]))
                plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
                     main=colnames(Posterior[[1]])[j], xlab="Lag",
                     ylab="Correlation")
                abline(h=(2*se), col="red", lty=2)
                abline(h=(-2*se), col="red", lty=2)
                for (n in 2:Chains) {
-                    z <- acf(Posterior[[n]][BurnIn:nn,j], plot=FALSE)
-                    se <- 1/sqrt(length(Posterior[[n]][BurnIn:nn,j]))
+                    z <- acf(Posterior[[n]][Stat.at:nn,j], plot=FALSE)
+                    se <- 1/sqrt(length(Posterior[[n]][Stat.at:nn,j]))
                     lines(z$lag, z$acf, col=n)}
                }
           else {plot(0,0, main=paste(colnames(Posterior[[1]])[j],
@@ -85,30 +86,30 @@ plot.demonoid.hpc <- function(x, BurnIn=1, Data=NULL, PDF=FALSE,
      ### Plot Deviance
      Deviance <- list()
      for (i in 1:Chains) {Deviance[[i]] <- x[[i]][["Deviance"]]}
-     plot(BurnIn:nn, Deviance[[1]][BurnIn:nn],
-          ylim=c(min(sapply(Deviance, function(x) {min(x[BurnIn:nn])})),
-               max(sapply(Deviance, function(x) {max(x[BurnIn:nn])}))),
+     plot(Stat.at:nn, Deviance[[1]][Stat.at:nn],
+          ylim=c(min(sapply(Deviance, function(x) {min(x[Stat.at:nn])})),
+               max(sapply(Deviance, function(x) {max(x[Stat.at:nn])}))),
           type="l", xlab="Iterations", ylab="Value", main="Deviance")
      for (n in 2:Chains) {
-          lines(BurnIn:nn, Deviance[[n]][BurnIn:nn], col=n)}
-     plot(density(Deviance[[1]][BurnIn:nn]),
+          lines(Stat.at:nn, Deviance[[n]][Stat.at:nn], col=n)}
+     plot(density(Deviance[[1]][Stat.at:nn]),
           xlab="Value", main="Deviance")
-     polygon(density(Deviance[[1]][BurnIn:nn]),
+     polygon(density(Deviance[[1]][Stat.at:nn]),
           col="black", border="black")
      for (n in 2:Chains) {
-          lines(density(Deviance[[n]][BurnIn:nn]), col=n)}
+          lines(density(Deviance[[n]][Stat.at:nn]), col=n)}
      abline(v=0, col="red", lty=2)
      #### Only plot an ACF if there's > 1 unique values
-     if(!is.constant(Deviance[[1]][BurnIn:nn])) {
-          z <- acf(Deviance[[1]][BurnIn:nn], plot=FALSE)
-          se <- 1/sqrt(length(Deviance[[1]][BurnIn:nn]))
+     if(!is.constant(Deviance[[1]][Stat.at:nn])) {
+          z <- acf(Deviance[[1]][Stat.at:nn], plot=FALSE)
+          se <- 1/sqrt(length(Deviance[[1]][Stat.at:nn]))
           plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
                main="Deviance", xlab="Lag", ylab="Correlation")
           abline(h=(2*se), col="red", lty=2)
           abline(h=(-2*se), col="red", lty=2)
           for (n in 2:Chains) {
-               z <- acf(Deviance[[n]][BurnIn:nn], plot=FALSE)
-               se <- 1/sqrt(length(Deviance[[n]][BurnIn:nn]))
+               z <- acf(Deviance[[n]][Stat.at:nn], plot=FALSE)
+               se <- 1/sqrt(length(Deviance[[n]][Stat.at:nn]))
                lines(z$lag, z$acf, col=n)}
           }
      else {plot(0,0, main="Deviance is a constant.")}
@@ -119,31 +120,31 @@ plot.demonoid.hpc <- function(x, BurnIn=1, Data=NULL, PDF=FALSE,
      for (i in 1:Chains) {
           Monitor[[i]] <- matrix(x[[i]][["Monitor"]], nn, J)}
      for (j in 1:J) {
-          plot(BurnIn:nn, Monitor[[1]][BurnIn:nn,j],
-               ylim=c(min(sapply(Monitor, function(x) {min(x[BurnIn:nn,j])})),
-                    max(sapply(Monitor, function(x) {max(x[BurnIn:nn,j])}))),
+          plot(Stat.at:nn, Monitor[[1]][Stat.at:nn,j],
+               ylim=c(min(sapply(Monitor, function(x) {min(x[Stat.at:nn,j])})),
+                    max(sapply(Monitor, function(x) {max(x[Stat.at:nn,j])}))),
                type="l", xlab="Iterations", ylab="Value",
                main=Data$mon.names[j])
           for (n in 2:Chains) {
-               lines(BurnIn:nn, Monitor[[n]][BurnIn:nn,j], col=n)}
-          plot(density(Monitor[[1]][BurnIn:nn,j]),
+               lines(Stat.at:nn, Monitor[[n]][Stat.at:nn,j], col=n)}
+          plot(density(Monitor[[1]][Stat.at:nn,j]),
                xlab="Value", main=Data$mon.names[j])
-          polygon(density(Monitor[[1]][BurnIn:nn,j]), col="black",
+          polygon(density(Monitor[[1]][Stat.at:nn,j]), col="black",
                border="black")
           for (n in 2:Chains) {
-               lines(density(Monitor[[n]][BurnIn:nn,j]), col=n)}
+               lines(density(Monitor[[n]][Stat.at:nn,j]), col=n)}
           abline(v=0, col="red", lty=2)
           ### Only plot an ACF if there's > 1 unique values
-          if(!is.constant(Monitor[[1]][BurnIn:nn,j])) {
-               z <- acf(Monitor[[1]][BurnIn:nn,j], plot=FALSE)
-               se <- 1/sqrt(length(Monitor[[1]][BurnIn:nn,j]))
+          if(!is.constant(Monitor[[1]][Stat.at:nn,j])) {
+               z <- acf(Monitor[[1]][Stat.at:nn,j], plot=FALSE)
+               se <- 1/sqrt(length(Monitor[[1]][Stat.at:nn,j]))
                plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
                     main=Data$mon.names[j], xlab="Lag", ylab="Correlation")
                abline(h=(2*se), col="red", lty=2)
                abline(h=(-2*se), col="red", lty=2)
                for (n in 2:Chains) {
-                    z <- acf(Monitor[[n]][BurnIn:nn,j], plot=FALSE)
-                    se <- 1/sqrt(length(Monitor[[n]][BurnIn:nn,j]))
+                    z <- acf(Monitor[[n]][Stat.at:nn,j], plot=FALSE)
+                    se <- 1/sqrt(length(Monitor[[n]][Stat.at:nn,j]))
                     lines(z$lag, z$acf, col=n)}
                }
           else {plot(0,0, main=paste(Data$mon.names[j], "is a constant."))}
